# Copyright (c) 2022, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

from typing import Optional

from ngcbpc.api.configuration import Configuration
from ngcbpc.util.utils import format_org_team

PAGE_SIZE = 1000


class TenantAPI:
    def __init__(self, connection):
        self.config = Configuration()
        self.connection = connection

    @staticmethod
    def _get_tenant_endpoint(org_name=None, team_name=None):
        org_team = format_org_team(org_name, team_name, plural_form=False)
        return "/".join(["v2", org_team, "forge", "tenant"])

    def info(self, org: Optional[str] = None, team: Optional[str] = None, statistics: Optional[bool] = None):
        self.config.validate_configuration()
        org_name = org or self.config.org_name
        team_name = team or self.config.team_name
        ep = self._get_tenant_endpoint(org_name, team_name)
        url = f"{ep}/current"
        resp = self.connection.make_api_request(
            "GET", url, auth_org=org_name, auth_team=team_name, operation_name="tenant_info"
        )
        stats = None
        if statistics:
            url = f"{ep}/current/stats"
            stats = self.connection.make_api_request(
                "GET",
                url,
                auth_org=org_name,
                auth_team=team_name,
                operation_name="tenant_stats",
            )
        return resp, stats


class GuestTenantAPI(TenantAPI):
    pass
